@@ -8,14 +8,18 @@ import sys
 
 from osc import commandline, babysitter
 
+try:
 # this is a hack to make osc work as expected with utf-8 characters,
 # no matter how site.py is set...
-reload(sys)
-loc = locale.getpreferredencoding()
-if not loc:
-    loc = sys.getpreferredencoding()
-sys.setdefaultencoding(loc)
-del sys.setdefaultencoding
+    reload(sys)
+    loc = locale.getpreferredencoding()
+    if not loc:
+        loc = sys.getpreferredencoding()
+    sys.setdefaultencoding(loc)
+    del sys.setdefaultencoding
+except NameError:
+    #reload, neither setdefaultencoding are in python3
+    pass
 
 osccli = commandline.Osc()
 
