@@ -44,7 +44,7 @@ change_personality = {
         }
 
 # FIXME: qemu_can_build should not be needed anymore since OBS 2.3
-qemu_can_build = [ 'armv4l', 'armv5el', 'armv5l', 'armv6l', 'armv7l', 'armv6el', 'armv7el', 'armv7hl', 'armv8el',
+qemu_can_build = [ 'armv4l', 'armv5el', 'armv5l', 'armv6l', 'armv7l', 'armv6el', 'armv6hl', 'armv7el', 'armv7hl', 'armv8el',
                    'sh4', 'mips', 'mipsel',
                    'ppc', 'ppc64',
                    's390', 's390x',
@@ -57,13 +57,15 @@ can_also_build = {
              'armv7l' :[                                         'armv4l', 'armv5l', 'armv6l', 'armv7l', 'armv5el', 'armv6el', 'armv7el'            ],
              'armv5el':[                                         'armv4l', 'armv5l', 'armv5el'                                  ], # not existing arch, just for compatibility
              'armv6el':[                                         'armv4l', 'armv5l', 'armv6l', 'armv5el', 'armv6el'                       ], # not existing arch, just for compatibility
+             'armv6hl':[                                         'armv4l', 'armv5l', 'armv6l', 'armv5el', 'armv6el'                       ],
              'armv7el':[                                         'armv4l', 'armv5l', 'armv6l', 'armv7l', 'armv5el', 'armv6el', 'armv7el'            ], # not existing arch, just for compatibility
              'armv7hl':[                        'armv7hl'                                                             ], # not existing arch, just for compatibility
              'armv8el':[                                         'armv4l', 'armv5el', 'armv6el', 'armv7el', 'armv8el' ], # not existing arch, just for compatibility
              'armv8l' :[                                         'armv4l', 'armv5el', 'armv6el', 'armv7el', 'armv8el' ], # not existing arch, just for compatibility
              'armv5tel':[                                        'armv4l', 'armv5el',                                 'armv5tel' ], 
              's390x':  ['s390' ],
-             'ppc64':  [                        'ppc', 'ppc64' ],
+             'ppc64':  [                        'ppc', 'ppc64', 'ppc64p7', 'ppc64le' ],
+             'ppc64le':[ 'ppc64le' ],
              'i586':   [                'i386' ],
              'i686':   [        'i586', 'i386' ],
              'x86_64': ['i686', 'i586', 'i386' ],
@@ -135,12 +137,15 @@ class Buildinfo:
         self.projects = {}
         self.keys = []
         self.prjkeys = []
+        self.pathes = []
         for node in root.findall('bdep'):
             p = Pac(node, self.buildarch, self.pacsuffix,
                     apiurl, localpkgs)
             if p.project:
                 self.projects[p.project] = 1
             self.deps.append(p)
+        for node in root.findall('path'):
+            self.pathes.append(node.get('project')+"/"+node.get('repository'))
 
         self.vminstall_list = [ dep.name for dep in self.deps if dep.vminstall ]
         self.preinstall_list = [ dep.name for dep in self.deps if dep.preinstall ]
@@ -359,8 +364,8 @@ def create_deps(pkgqs):
 
 trustprompt = """Would you like to ...
 0 - quit (default)
-1 - trust packages from '%(project)s' always
-2 - trust them just this time
+1 - always trust packages from '%(project)s'
+2 - trust packages just this time
 ? """
 def check_trusted_projects(apiurl, projects):
     trusted = config['api_host_options'][apiurl]['trusted_prj']
@@ -775,11 +780,9 @@ def main(apiurl, opts, argv):
 
     # Make packages from buildinfo available as repos for kiwi
     if build_type == 'kiwi':
-        if not os.path.exists('repos'):
-            os.mkdir('repos')
-        else:
+        if os.path.exists('repos'):
             shutil.rmtree('repos')
-            os.mkdir('repos')
+        os.mkdir('repos')
         for i in bi.deps:
             if not i.extproject:
                 # remove
@@ -817,6 +820,61 @@ def main(apiurl, opts, argv):
                             os.link(path + "/" + filename, tffn)
                         else:
                             os.symlink(path + "/" + filename, tffn)
+        # Is a obsrepositories tag used?
+        try:
+            tree = ET.parse(build_descr)
+        except:
+            print('could not parse the kiwi file:', file=sys.stderr)
+            print(open(build_descr).read(), file=sys.stderr)
+            sys.exit(1)
+        root = tree.getroot()
+        # product
+        for xml in root.findall('instsource'):
+            if xml.find('instrepo').find('source').get('path') == 'obsrepositories:/':
+                print("obsrepositories:/ for product builds is not yet supported in osc!")
+                sys.exit(1)
+        # appliance
+        expand_obsrepos=None
+        for xml in root.findall('repository'):
+            if xml.find('source').get('path') == 'obsrepositories:/':
+                expand_obsrepos=True
+        if expand_obsrepos:
+          buildargs.append('--kiwi-parameter')
+          buildargs.append('--ignore-repos')
+          for xml in root.findall('repository'):
+              if xml.find('source').get('path') == 'obsrepositories:/':
+                  for path in bi.pathes:
+                      if not os.path.isdir("repos/"+path):
+                          continue
+                      buildargs.append('--kiwi-parameter')
+                      buildargs.append('--add-repo')
+                      buildargs.append('--kiwi-parameter')
+                      buildargs.append("repos/"+path)
+                      buildargs.append('--kiwi-parameter')
+                      buildargs.append('--add-repotype')
+                      buildargs.append('--kiwi-parameter')
+                      buildargs.append('rpm-md')
+                      if xml.get('priority'):
+                          buildargs.append('--kiwi-parameter')
+                          buildargs.append('--add-repoprio='+xml.get('priority'))
+              else:
+                   m = re.match(r"obs://[^/]+/([^/]+)/(\S+)", xml.find('source').get('path'))
+                   if not m:
+                       # short path without obs instance name
+                       m = re.match(r"obs://([^/]+)/(.+)", xml.find('source').get('path'))
+                   project=m.group(1).replace(":",":/")
+                   repo=m.group(2)
+                   buildargs.append('--kiwi-parameter')
+                   buildargs.append('--add-repo')
+                   buildargs.append('--kiwi-parameter')
+                   buildargs.append("repos/"+project+"/"+repo)
+                   buildargs.append('--kiwi-parameter')
+                   buildargs.append('--add-repotype')
+                   buildargs.append('--kiwi-parameter')
+                   buildargs.append('rpm-md')
+                   if xml.get('priority'):
+                       buildargs.append('--kiwi-parameter')
+                       buildargs.append('--add-repopriority='+xml.get('priority'))
 
     if vm_type == "xen" or vm_type == "kvm" or vm_type == "lxc":
         print('Skipping verification of package signatures due to secure VM build')
