@@ -1,8 +1,11 @@
-import ar
+
+from __future__ import print_function
+
+from . import ar
 import os.path
 import re
 import tarfile
-import packagequery
+from . import packagequery
 
 class DebError(packagequery.PackageError):
     pass
@@ -23,18 +26,22 @@ class DebQuery(packagequery.PackageQuery):
         arfile.read()
         debbin = arfile.get_file('debian-binary')
         if debbin is None:
-            raise DebError('no debian binary')
+            raise DebError(self.__path, 'no debian binary')
         if debbin.read() != '2.0\n':
-            raise DebError('invalid debian binary format')
+            raise DebError(self.__path, 'invalid debian binary format')
         control = arfile.get_file('control.tar.gz')
         if control is None:
-            raise DebError('missing control.tar.gz')
-        # XXX: python24 relies on a name
+            raise DebError(self.__path, 'missing control.tar.gz')
+        # XXX: python2.4 relies on a name
         tar = tarfile.open(name = 'control.tar.gz', fileobj = control)
         try:
-            control = tar.extractfile('./control')
+            name = './control'
+            # workaround for python2.4's tarfile module
+            if 'control' in tar.getnames():
+                name = 'control'
+            control = tar.extractfile(name)
         except KeyError:
-            raise DebError('missing \'control\' file in control.tar.gz')
+            raise DebError(self.__path, 'missing \'control\' file in control.tar.gz')
         self.__parse_control(control, all_tags, *extra_tags)
 
     def __parse_control(self, control, all_tags = False, *extra_tags):
@@ -163,12 +170,12 @@ if __name__ == '__main__':
     import sys
     try:
         debq = DebQuery.query(sys.argv[1])
-    except DebError, e:
-        print e.msg
+    except DebError as e:
+        print(e.msg)
         sys.exit(2)
-    print debq.name(), debq.version(), debq.release(), debq.arch()
-    print debq.description()
-    print '##########'
-    print '\n'.join(debq.provides())
-    print '##########'
-    print '\n'.join(debq.requires())
+    print(debq.name(), debq.version(), debq.release(), debq.arch())
+    print(debq.description())
+    print('##########')
+    print('\n'.join(debq.provides()))
+    print('##########')
+    print('\n'.join(debq.requires()))
