@@ -1,3 +1,6 @@
+
+from __future__ import print_function
+
 class PackageError(Exception):
     """base class for all package related errors"""
     def __init__(self, fname, msg):
@@ -91,18 +94,18 @@ class PackageQuery:
         extra_tags = ()
         pkgquery = None
         if magic[:4] == '\xed\xab\xee\xdb':
-            import rpmquery
+            from . import rpmquery
             pkgquery = rpmquery.RpmQuery(f)
             extra_tags = extra_rpmtags
         elif magic == '!<arch>':
-            import debquery
+            from . import debquery
             pkgquery = debquery.DebQuery(f)
             extra_tags = extra_debtags
         elif magic[:5] == '<?xml':
             f.close()
             return None
         elif magic[:5] == '\375\067zXZ' or magic[:2] == '\037\213':
-            import archquery
+            from . import archquery
             pkgquery = archquery.ArchQuery(f)
         else:
             raise PackageError(filename, 'unsupported package type. magic: \'%s\'' % magic)
@@ -114,14 +117,14 @@ if __name__ == '__main__':
     import sys
     try:
         pkgq = PackageQuery.query(sys.argv[1])
-    except PackageError, e:
-        print e.msg
+    except PackageError as e:
+        print(e.msg)
         sys.exit(2)
-    print pkgq.name()
-    print pkgq.version()
-    print pkgq.release()
-    print pkgq.description()
-    print '##########'
-    print '\n'.join(pkgq.provides())
-    print '##########'
-    print '\n'.join(pkgq.requires())
+    print(pkgq.name())
+    print(pkgq.version())
+    print(pkgq.release())
+    print(pkgq.description())
+    print('##########')
+    print('\n'.join(pkgq.provides()))
+    print('##########')
+    print('\n'.join(pkgq.requires()))
