@@ -2,6 +2,7 @@ import osc.core
 import osc.oscerr
 import os
 import sys
+import urllib2
 from common import GET, PUT, POST, DELETE, OscTestCase
 from xml.etree import cElementTree as ET
 FIXTURES_DIR = os.path.join(os.getcwd(), 'commit_fixtures')
@@ -17,10 +18,12 @@ class TestCommit(OscTestCase):
         return FIXTURES_DIR
 
     @GET('http://localhost/source/osctest/simple?rev=latest', file='testSimple_filesremote')
+    @POST('http://localhost/source/osctest/simple?cmd=getprojectservices',
+          exp='', text='<services />')
     @POST('http://localhost/source/osctest/simple?comment=&cmd=commitfilelist&user=Admin',
           file='testSimple_missingfilelist', expfile='testSimple_lfilelist')
     @PUT('http://localhost/source/osctest/simple/nochange?rev=repository',
-         exp='This file didn\'t change but\nis modified.\n', text=rev_dummy)
+          exp='This file didn\'t change but\nis modified.\n', text=rev_dummy)
     @POST('http://localhost/source/osctest/simple?comment=&cmd=commitfilelist&user=Admin',
           file='testSimple_cfilesremote', expfile='testSimple_lfilelist')
     def test_simple(self):
@@ -38,6 +41,8 @@ class TestCommit(OscTestCase):
         self._check_status(p, 'merge', ' ')
 
     @GET('http://localhost/source/osctest/add?rev=latest', file='testAddfile_filesremote')
+    @POST('http://localhost/source/osctest/add?cmd=getprojectservices',
+          exp='', text='<services />')
     @POST('http://localhost/source/osctest/add?comment=&cmd=commitfilelist&user=Admin',
           file='testAddfile_missingfilelist', expfile='testAddfile_lfilelist')
     @PUT('http://localhost/source/osctest/add/add?rev=repository',
@@ -61,6 +66,8 @@ class TestCommit(OscTestCase):
         self._check_status(p, 'nochange', ' ')
 
     @GET('http://localhost/source/osctest/delete?rev=latest', file='testDeletefile_filesremote')
+    @POST('http://localhost/source/osctest/delete?cmd=getprojectservices',
+          exp='', text='<services />')
     @POST('http://localhost/source/osctest/delete?comment=&cmd=commitfilelist&user=Admin',
           file='testDeletefile_cfilesremote', expfile='testDeletefile_lfilelist')
     def test_deletefile(self):
@@ -78,6 +85,8 @@ class TestCommit(OscTestCase):
         self._check_status(p, 'merge', ' ')
 
     @GET('http://localhost/source/osctest/conflict?rev=latest', file='testConflictfile_filesremote')
+    @POST('http://localhost/source/osctest/conflict?cmd=getprojectservices',
+          exp='', text='<services />')
     def test_conflictfile(self):
         """package has a file which is in conflict state"""
         self._change_to_pkg('conflict')
@@ -89,6 +98,8 @@ class TestCommit(OscTestCase):
         self._check_conflictlist('merge\n')
 
     @GET('http://localhost/source/osctest/nochanges?rev=latest', file='testNoChanges_filesremote')
+    @POST('http://localhost/source/osctest/nochanges?cmd=getprojectservices',
+          exp='', text='<services />')
     def test_nochanges(self):
         """package has no changes (which can be committed)"""
         self._change_to_pkg('nochanges')
@@ -102,6 +113,8 @@ class TestCommit(OscTestCase):
         self._check_status(p, 'nochange', ' ')
 
     @GET('http://localhost/source/osctest/multiple?rev=latest', file='testMultiple_filesremote')
+    @POST('http://localhost/source/osctest/multiple?cmd=getprojectservices',
+          exp='', text='<services />')
     @POST('http://localhost/source/osctest/multiple?comment=&cmd=commitfilelist&user=Admin',
           file='testMultiple_missingfilelist', expfile='testMultiple_lfilelist')
     @PUT('http://localhost/source/osctest/multiple/nochange?rev=repository', exp='This file did change.\n', text=rev_dummy)
@@ -129,6 +142,8 @@ class TestCommit(OscTestCase):
         self._check_status(p, 'nochange', ' ')
 
     @GET('http://localhost/source/osctest/multiple?rev=latest', file='testPartial_filesremote')
+    @POST('http://localhost/source/osctest/multiple?cmd=getprojectservices',
+          exp='', text='<services />')
     @POST('http://localhost/source/osctest/multiple?comment=&cmd=commitfilelist&user=Admin',
           file='testPartial_missingfilelist', expfile='testPartial_lfilelist')
     @PUT('http://localhost/source/osctest/multiple/add?rev=repository', exp='added file\n', text=rev_dummy)
@@ -154,6 +169,8 @@ class TestCommit(OscTestCase):
         self.assertRaises(osc.oscerr.OscIOError, p.status, 'foo')
 
     @GET('http://localhost/source/osctest/simple?rev=latest', file='testSimple_filesremote')
+    @POST('http://localhost/source/osctest/simple?cmd=getprojectservices',
+          exp='', text='<services />')
     @POST('http://localhost/source/osctest/simple?comment=&cmd=commitfilelist&user=Admin',
           file='testSimple_missingfilelist', expfile='testSimple_lfilelist')
     @PUT('http://localhost/source/osctest/simple/nochange?rev=repository', exp='This file didn\'t change but\nis modified.\n',
@@ -170,6 +187,8 @@ class TestCommit(OscTestCase):
         self._check_status(p, 'nochange', 'M')
 
     @GET('http://localhost/source/osctest/allstates?rev=latest', file='testPartial_filesremote')
+    @POST('http://localhost/source/osctest/allstates?cmd=getprojectservices',
+          exp='', text='<services />')
     @POST('http://localhost/source/osctest/allstates?comment=&cmd=commitfilelist&user=Admin',
           file='testAllStates_missingfilelist', expfile='testAllStates_lfilelist')
     @PUT('http://localhost/source/osctest/allstates/add?rev=repository', exp='added file\n', text=rev_dummy)
@@ -198,6 +217,8 @@ class TestCommit(OscTestCase):
         self._check_status(p, 'test', ' ')
 
     @GET('http://localhost/source/osctest/add?rev=latest', file='testAddfile_filesremote')
+    @POST('http://localhost/source/osctest/add?cmd=getprojectservices',
+          exp='', text='<services />')
     @POST('http://localhost/source/osctest/add?comment=&cmd=commitfilelist&user=Admin',
           file='testAddfile_cfilesremote', expfile='testAddfile_lfilelist')
     def test_remoteexists(self):
@@ -217,6 +238,8 @@ class TestCommit(OscTestCase):
         self._check_status(p, 'nochange', ' ')
 
     @GET('http://localhost/source/osctest/branch?rev=latest', file='testExpand_filesremote')
+    @POST('http://localhost/source/osctest/branch?cmd=getprojectservices',
+          exp='', text='<services />')
     @POST('http://localhost/source/osctest/branch?comment=&cmd=commitfilelist&user=Admin&keeplink=1',
           file='testExpand_missingfilelist', expfile='testExpand_lfilelist')
     @PUT('http://localhost/source/osctest/branch/simple?rev=repository', exp='simple modified file.\n', text=rev_dummy)
@@ -234,6 +257,8 @@ class TestCommit(OscTestCase):
         self._check_status(p, 'simple', ' ')
 
     @GET('http://localhost/source/osctest/added_missing?rev=latest', file='testAddedMissing_filesremote')
+    @POST('http://localhost/source/osctest/added_missing?cmd=getprojectservices',
+          exp='', text='<services />')
     def test_added_missing(self):
         """commit an added file which is missing"""
         self._change_to_pkg('added_missing')
@@ -245,6 +270,8 @@ class TestCommit(OscTestCase):
         self._check_status(p, 'add', '!')
 
     @GET('http://localhost/source/osctest/added_missing?rev=latest', file='testAddedMissing_filesremote')
+    @POST('http://localhost/source/osctest/added_missing?cmd=getprojectservices',
+          exp='', text='<services />')
     @POST('http://localhost/source/osctest/added_missing?comment=&cmd=commitfilelist&user=Admin',
           file='testAddedMissing_missingfilelist', expfile='testAddedMissing_lfilelist')
     @PUT('http://localhost/source/osctest/added_missing/bar?rev=repository', exp='foobar\n', text=rev_dummy)
@@ -261,6 +288,25 @@ class TestCommit(OscTestCase):
         self._check_status(p, 'add', '!')
         self._check_status(p, 'bar', ' ')
 
+    @GET('http://localhost/source/osctest/simple?rev=latest', file='testSimple_filesremote')
+    @POST('http://localhost/source/osctest/simple?cmd=getprojectservices',
+          exp='', text='<services />')
+    @POST('http://localhost/source/osctest/simple?comment=&cmd=commitfilelist&user=Admin',
+          file='testSimple_missingfilelist', expfile='testSimple_lfilelist')
+    @PUT('http://localhost/source/osctest/simple/nochange?rev=repository',
+          exp='This file didn\'t change but\nis modified.\n', text=rev_dummy)
+    @POST('http://localhost/source/osctest/simple?comment=&cmd=commitfilelist&user=Admin', 
+          expfile='testSimple_lfilelist', text='an error occured', code=500)
+    def test_commitfilelist_error(self):
+        """commit modified file but when committing the filelist the server returns status 500 (see ticket #65)"""
+        self._change_to_pkg('simple')
+        p = osc.core.Package('.')
+        self._check_status(p, 'nochange', 'M')
+        self.assertRaises(urllib2.HTTPError, p.commit)
+        exp = 'Sending    nochange\nTransmitting file data .'
+        self.assertEqual(sys.stdout.getvalue(), exp)
+        self._check_status(p, 'nochange', 'M')
+
 if __name__ == '__main__':
     import unittest
     unittest.main()
